@@ -35,13 +35,16 @@ sha1 digest of the concatenation of the master password and the domain key::
 
 """
 
-import string
+import optparse
 import sha
+import string
+import sys
 from itertools import izip
 from getpass import getpass
 
 ONE_BYTE = 2 ** 8
-LENGTH = 8 # default password length
+DEFAULT_LENGTH = 8 # default password length
+DEFAULT_ALPHABET = string.lowercase + string.uppercase + string.digits
 
 def bytes2number(bs):
     """Convert a python string (of bytes) into a python integer
@@ -101,17 +104,18 @@ def bytes2string(bs, alphabet):
 
 
 def make_password(master_password, domain_key, lowercase=True, uppercase=True,
-                  digits=True, length=LENGTH):
+                  digits=True, length=DEFAULT_LENGTH, alphabet=None):
     """Build a password out of a master key and a domain key"""
 
     # build the sha1 hash of the concatenation of the keys
     hash = sha.new(master_password + domain_key).digest()
 
-    # determine the list of acceptable characters
-    alphabet = ''
-    alphabet += lowercase and string.lowercase or ''
-    alphabet += uppercase and string.uppercase or ''
-    alphabet += digits and string.digits or ''
+    if alphabet is None:
+        # determine the list of acceptable characters
+        alphabet = ''
+        alphabet += lowercase and string.lowercase or ''
+        alphabet += uppercase and string.uppercase or ''
+        alphabet += digits and string.digits or ''
 
     if not alphabet:
         raise ValueError('empty alphabet')
@@ -121,12 +125,36 @@ def make_password(master_password, domain_key, lowercase=True, uppercase=True,
     return bytes2string(hash, alphabet)[:length]
 
 
+def parse_args(args):
+    usage = "vkr -l 10 -a abcdefghijklmnopqrstuvwyz0123456789"
+    parser = optparse.OptionParser(usage=usage)
+
+    parser.add_option('-l', '--lenght',
+                      dest='length',
+                      default=DEFAULT_LENGTH,
+                      type="int",
+                      help=("Lenght of the generated password (default: %d)" %
+                            DEFAULT_LENGTH))
+
+    parser.add_option('-a', '--alphabet',
+                      dest='alphabet',
+                      default=DEFAULT_ALPHABET,
+                      help=("Characters to be used for the generated password"
+                            " (default: %s)" % DEFAULT_ALPHABET))
+
+    return parser.parse_args(args=args)
+
+
 def main():
+    options, _ = parse_args(sys.argv)
+
     # password and domain prefix are read interactively from stdin to avoid
     # password data to be stored in the shell command history
     master_password = getpass("master password: ")
     domain_key = raw_input("domain key [e.g. 'login@host']: ")
-    print "your password is:", make_password(master_password, domain_key)
+    print "your password is:", make_password(master_password, domain_key,
+                                             length=options.length,
+                                             alphabet=options.alphabet)
     print "please clean your console (ctrl-L) after usage"
 
 
